
#ifndef _C10_ev480_
#define _C10_ev480_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1119_10024(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit480(void);
extern char *(*R9720[])();
extern long O7928[];

#ifdef __cplusplus
}
#endif

#endif
